netapp_ontap.models.onboard_key_manager_configurable_status API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.onboard_key_manager_configurable_status`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class OnboardKeyManagerConfigurableStatusSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the OnboardKeyManagerConfigurableStatus object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `code GET`

    Code corresponding to the status message. Returns a 0 if the Onboard Key Manager can be configured in the cluster.

    Example: 65537300

  `message GET`

    Reason that Onboard Key Manager cannot be configured in the cluster.

    Example: No platform support for volume encryption in following nodes - node1, node2.

  `supported GET`

    Set to true if the Onboard Key Manager can be configured in the cluster.